@@ -28,8 +28,7 @@
 
 #include <QObject>
 
-namespace IncidenceEditorNG
-{
+namespace IncidenceEditorNG {
 class ConflictResolver;
 }
 
@@ -50,8 +49,7 @@ private Q_SLOTS:
 
 private:
     void insertAttendees();
-    void addAttendee(const QString &email, const KCalCore::FreeBusy::Ptr &fb,
-                     KCalCore::Attendee::Role role = KCalCore::Attendee::ReqParticipant);
+    void addAttendee(const QString &email, const KCalCore::FreeBusy::Ptr &fb, KCalCore::Attendee::Role role = KCalCore::Attendee::ReqParticipant);
     QList<CalendarSupport::FreeBusyItem::Ptr> attendees;
     QWidget *parent;
     IncidenceEditorNG::ConflictResolver *resolver;
