@@ -50,11 +50,11 @@ public:
     using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
     using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual
     IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui);
-    ~IncidenceAttendee();
+    ~IncidenceAttendee() override;
 
     void load(const KCalCore::Incidence::Ptr &incidence) override;
     void save(const KCalCore::Incidence::Ptr &incidence) override;
-    bool isDirty() const override;
+    Q_REQUIRED_RESULT bool isDirty() const override;
     void printDebugInfo() const override;
 
     AttendeeTableModel *dataModel() const;
@@ -63,7 +63,7 @@ public:
     AttendeeComboBoxDelegate *responseDelegate() const;
     AttendeeLineEditDelegate *attendeeDelegate() const;
 
-    int attendeeCount() const;
+    Q_REQUIRED_RESULT int attendeeCount() const;
 
 Q_SIGNALS:
     void attendeeCountChanged(int);
@@ -95,8 +95,7 @@ private Q_SLOTS:
 
     void slotConflictResolverAttendeeAdded(const QModelIndex &index, int first, int last);
     void slotConflictResolverAttendeeRemoved(const QModelIndex &index, int first, int last);
-    void slotConflictResolverAttendeeChanged(const QModelIndex &topLeft,
-                                             const QModelIndex &bottomRight);
+    void slotConflictResolverAttendeeChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void slotConflictResolverLayoutChanged();
     void slotFreeBusyAdded(const QModelIndex &index, int first, int last);
     void slotFreeBusyChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
@@ -105,8 +104,7 @@ private Q_SLOTS:
 
     void slotGroupSubstitutionAttendeeAdded(const QModelIndex &index, int first, int last);
     void slotGroupSubstitutionAttendeeRemoved(const QModelIndex &index, int first, int last);
-    void slotGroupSubstitutionAttendeeChanged(const QModelIndex &topLeft,
-                                              const QModelIndex &bottomRight);
+    void slotGroupSubstitutionAttendeeChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void slotGroupSubstitutionLayoutChanged();
 
 private:
@@ -128,20 +126,20 @@ private:
     void fillOrganizerCombo();
     void setActions(KCalCore::Incidence::IncidenceType actions);
 
-    Ui::EventOrTodoDesktop *mUi;
-    QWidget *mParentWidget;
-    ConflictResolver *mConflictResolver;
+    Ui::EventOrTodoDesktop *mUi = nullptr;
+    QWidget *mParentWidget = nullptr;
+    ConflictResolver *mConflictResolver = nullptr;
 
-    IncidenceDateTime *mDateTime;
+    IncidenceDateTime *mDateTime = nullptr;
     QString mOrganizer;
     QString mOldIconName;
 
     /** used dataModel to rely on*/
-    AttendeeTableModel *mDataModel;
-    AttendeeLineEditDelegate *mAttendeeDelegate;
-    AttendeeComboBoxDelegate *mStateDelegate;
-    AttendeeComboBoxDelegate *mRoleDelegate;
-    AttendeeComboBoxDelegate *mResponseDelegate;
+    AttendeeTableModel *mDataModel = nullptr;
+    AttendeeLineEditDelegate *mAttendeeDelegate = nullptr;
+    AttendeeComboBoxDelegate *mStateDelegate = nullptr;
+    AttendeeComboBoxDelegate *mRoleDelegate = nullptr;
+    AttendeeComboBoxDelegate *mResponseDelegate = nullptr;
 
     QMap<KCalCore::Attendee::Ptr, KContacts::ContactGroup> mGroupList;
     QMap<KJob *, KCalCore::Attendee::Ptr> mMightBeGroupJobs;
